@@ -13,6 +13,7 @@ use Data::Dumper;
 use Capture::Tiny ':all';
 use Slurp;
 use File::Slurp;
+use File::Spec;
 
 extends 'TestMethods::Base';
 
@@ -27,9 +28,8 @@ $ENV{'SLURM_ARRAY_TASK_ID'}=1;
 sub write_test_file {
     my $test_dir = shift;
 
-    my $t = "$test_dir/script/test002.1.sh";
-    open( my $fh, ">$t" );
-    print $fh <<EOF;
+    my $file = File::Spec->catdir( $test_dir, 'script', 'test001.1.sh' );
+    my $text = <<EOF;
 #TASK tags=Sample_PAG008_V4_E2
 gzip -f Sample_PAG008_V4_E2_read1_trimmomatic_1PE.fastq
 
@@ -43,7 +43,7 @@ gzip -f Sample_PAG008_V4_E2_read2_trimmomatic_1SE.fastq
 gzip -f Sample_PAG008_V4_E2_read2_trimmomatic_1PE.fastq
 EOF
 
-    close($fh);
+    write_file( $file, $text );
 }
 
 sub construct {
@@ -55,10 +55,10 @@ sub construct {
     my $test_dir     = $test_methods->make_test_dir();
     write_test_file($test_dir);
 
-    my $t = "$test_dir/script/test002.1.sh";
+    my $file = File::Spec->catdir( $test_dir, 'script', 'test001.1.sh' );
     MooseX::App::ParsedArgv->new(
         argv => [
-            "execute_array", "--infile", $t, '--commands', 1,
+            "execute_array", "--infile", $file, '--commands', 1,
             '--batch_index_start', 1,
         ]
     );
@@ -162,4 +162,34 @@ sub test_004 : Tags(use_batches) {
     remove_tree($test_dir);
 }
 
+sub test_005 : Tags(use_batches) {
+    my $test     = construct();
+    my $test_dir = getcwd();
+
+    my $fh = IO::File->new( $test->infile, q{<} );
+    my $cmds = $test->parse_cmd_file($fh);
+
+    write_file(
+'Sample_PAG008_V4_E2_read1_trimmomatic_1PE.fastq', 'THIS IS A FILE'
+    );
+
+    $test->cmd($cmds->[0]);
+    $test->_log_commands;
+
+    # diag($test->cmd);
+    # diag($test->data_tar);
+    # diag(Dumper $test->archive->list_files);
+    my $basename = $test->data_tar->basename('.tar.gz');
+    my $complete_file = File::Spec->catdir( $basename, 'job','complete.json' );
+    my $running_file = File::Spec->catdir( $basename, 'job','running.json' );
+
+    ok($test->archive->contains_file($complete_file));
+    ok($test->archive->contains_file($running_file));
+    # diag($test->archive->get_content($complete_file));
+    ok(1);
+
+    chdir($Bin);
+    remove_tree($test_dir);
+}
+
 1;
